EXPORTS
	??0CObexServerSendOperation@@IAE@VTUid@@AAVCMsvServerEntry@@HHAAVTRequestStatus@@@Z @ 1 NONAME ; protected: __thiscall CObexServerSendOperation::CObexServerSendOperation(class TUid,class CMsvServerEntry &,int,int,class TRequestStatus &)
	??0CObexSrvMtm@@IAE@AAVCRegisteredMtmDll@@PAVCMsvServerEntry@@@Z @ 2 NONAME ; protected: __thiscall CObexSrvMtm::CObexSrvMtm(class CRegisteredMtmDll &,class CMsvServerEntry *)
	??1CObexServerSendOperation@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CObexServerSendOperation::~CObexServerSendOperation(void)
	??1CObexSrvMtm@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CObexSrvMtm::~CObexSrvMtm(void)
	?ChangeL@CObexSrvMtm@@UAEXVTMsvEntry@@AAVTRequestStatus@@@Z @ 5 NONAME ; public: virtual void __thiscall CObexSrvMtm::ChangeL(class TMsvEntry,class TRequestStatus &)
	?CommandExpected@CObexSrvMtm@@UAEHXZ @ 6 NONAME ; public: virtual int __thiscall CObexSrvMtm::CommandExpected(void)
	?ConstructL@CObexServerSendOperation@@IAEXPBVTDesC16@@@Z @ 7 NONAME ; protected: void __thiscall CObexServerSendOperation::ConstructL(class TDesC16 const *)
	?ConstructL@CObexSrvMtm@@IAEXXZ @ 8 NONAME ; protected: void __thiscall CObexSrvMtm::ConstructL(void)
	?CopyFromLocalL@CObexSrvMtm@@UAEXABVCMsvEntrySelection@@JAAVTRequestStatus@@@Z @ 9 NONAME ; public: virtual void __thiscall CObexSrvMtm::CopyFromLocalL(class CMsvEntrySelection const &,long,class TRequestStatus &)
	?CopyToLocalL@CObexSrvMtm@@UAEXABVCMsvEntrySelection@@JAAVTRequestStatus@@@Z @ 10 NONAME ; public: virtual void __thiscall CObexSrvMtm::CopyToLocalL(class CMsvEntrySelection const &,long,class TRequestStatus &)
	?CopyWithinServiceL@CObexSrvMtm@@UAEXABVCMsvEntrySelection@@JAAVTRequestStatus@@@Z @ 11 NONAME ; public: virtual void __thiscall CObexSrvMtm::CopyWithinServiceL(class CMsvEntrySelection const &,long,class TRequestStatus &)
	?CreateL@CObexSrvMtm@@UAEXVTMsvEntry@@AAVTRequestStatus@@@Z @ 12 NONAME ; public: virtual void __thiscall CObexSrvMtm::CreateL(class TMsvEntry,class TRequestStatus &)
	?DeleteAllL@CObexSrvMtm@@UAEXABVCMsvEntrySelection@@AAVTRequestStatus@@@Z @ 13 NONAME ; public: virtual void __thiscall CObexSrvMtm::DeleteAllL(class CMsvEntrySelection const &,class TRequestStatus &)
	?DeleteL@CObexSrvMtm@@QAEXABVCMsvEntrySelection@@AAVTRequestStatus@@@Z @ 14 NONAME ; public: void __thiscall CObexSrvMtm::DeleteL(class CMsvEntrySelection const &,class TRequestStatus &)
	?DoCancel@CObexServerSendOperation@@MAEXXZ @ 15 NONAME ; protected: virtual void __thiscall CObexServerSendOperation::DoCancel(void)
	?DoCancel@CObexSrvMtm@@MAEXXZ @ 16 NONAME ; protected: virtual void __thiscall CObexSrvMtm::DoCancel(void)
	?DoComplete@CObexSrvMtm@@MAEXH@Z @ 17 NONAME ; protected: virtual void __thiscall CObexSrvMtm::DoComplete(int)
	?DoRunL@CObexSrvMtm@@MAEXXZ @ 18 NONAME ; protected: virtual void __thiscall CObexSrvMtm::DoRunL(void)
	?GetUserPasswordL@CObexServerSendOperation@@EAEXABVTDesC16@@@Z @ 19 NONAME ; private: virtual void __thiscall CObexServerSendOperation::GetUserPasswordL(class TDesC16 const &)
	?MoveFromLocalL@CObexSrvMtm@@UAEXABVCMsvEntrySelection@@JAAVTRequestStatus@@@Z @ 20 NONAME ; public: virtual void __thiscall CObexSrvMtm::MoveFromLocalL(class CMsvEntrySelection const &,long,class TRequestStatus &)
	?MoveToLocalL@CObexSrvMtm@@UAEXABVCMsvEntrySelection@@JAAVTRequestStatus@@@Z @ 21 NONAME ; public: virtual void __thiscall CObexSrvMtm::MoveToLocalL(class CMsvEntrySelection const &,long,class TRequestStatus &)
	?MoveWithinServiceL@CObexSrvMtm@@UAEXABVCMsvEntrySelection@@JAAVTRequestStatus@@@Z @ 22 NONAME ; public: virtual void __thiscall CObexSrvMtm::MoveWithinServiceL(class CMsvEntrySelection const &,long,class TRequestStatus &)
	?Progress@CObexSrvMtm@@UAEABVTDesC8@@XZ @ 23 NONAME ; public: virtual class TDesC8 const & __thiscall CObexSrvMtm::Progress(void)
	?ProgressL@CObexServerSendOperation@@QAEABVTDesC8@@XZ @ 24 NONAME ; public: class TDesC8 const & __thiscall CObexServerSendOperation::ProgressL(void)
	?RunL@CObexServerSendOperation@@EAEXXZ @ 25 NONAME ; private: virtual void __thiscall CObexServerSendOperation::RunL(void)
	?SetInitialEntry@CObexSrvMtm@@QAEXPAVCMsvServerEntry@@@Z @ 26 NONAME ; public: void __thiscall CObexSrvMtm::SetInitialEntry(class CMsvServerEntry *)
	?SecondPhaseObexClientInitL@CObexServerSendOperation@@UAEXXZ @ 27 NONAME ; public: virtual void __thiscall CObexServerSendOperation::SecondPhaseObexClientInitL(void)
	??0CObexServerSendOperation@@IAE@VTUid@@AAVCMsvServerEntry@@HHAAVTRequestStatus@@H@Z @ 28 NONAME ; protected: __thiscall CObexServerSendOperation::CObexServerSendOperation(class TUid,class CMsvServerEntry &,int,int,class TRequestStatus &,int)
	?CompletingObserver@CObexServerSendOperation@@MAEHH@Z @ 29 NONAME ; protected: virtual int __thiscall CObexServerSendOperation::CompletingObserver(int)

